import { Component, forwardRef, HostListener, Input, ViewChild, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import 'bootstrap-datepicker';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const BASE_OPTION = /** @type {?} */ ({ autoclose: true, format: 'dd/mm/yyyy' });
const th_TH = /** @type {?} */ (Object.assign({}, BASE_OPTION, { language: 'th-TH' }));
const en_GB = /** @type {?} */ (Object.assign({}, BASE_OPTION, { language: 'th-GB' }));
const NGQ_DATETIME_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgqDatepickerComponent),
    multi: true
};
class NgqDatepickerComponent {
    constructor() {
        this.propagateChange = _ => { };
        this.onTouched = () => { };
    }
    /**
     * @param {?} opts
     * @return {?}
     */
    set datePickerOptions(opts) {
        this._datePickerOptions = opts;
        if (this.input) {
            // destroy old datepicker
            jQuery(this.input.nativeElement).datepicker('destroy');
            // change value in text box follow option.language
            const /** @type {?} */ newVal = new Intl.DateTimeFormat(this._datePickerOptions.language).format(this._date);
            jQuery(this.input.nativeElement).val(newVal);
            // init datepicker
            this.initDatepicker();
        }
    }
    /**
     * @return {?}
     */
    initDatepicker() {
        if (this.input) {
            this._datepicker = jQuery(this.input.nativeElement).datepicker(this._datePickerOptions);
            this._datepicker.datepicker().on('changeDate', (e) => {
                this._date = e.date;
                this.propagateChange(this._date);
            });
            this._datepicker.datepicker('update', this._date);
            this._datepicker.prop('disabled', this._isDisabled);
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.initDatepicker();
    }
    /**
     * @param {?} obj
     * @return {?}
     */
    writeValue(obj) {
        this._date = obj;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.propagateChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) { }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this._isDisabled = isDisabled;
    }
}
NgqDatepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngq-datepicker',
                template: `<div *ngIf="!hideIcon" class="input-group">
  <input #input type="text" [attr.class]="class" [attr.id]="id" [attr.placeholder]="placeholder">
  <div class="input-group-addon" (click)="this._datepicker.datepicker('show')">
    <span class="glyphicon glyphicon-calendar"></span>
  </div>
</div>
<input *ngIf="hideIcon" #input type="text" [attr.class]="class" [attr.id]="id" [attr.placeholder]="placeholder">
`,
                styles: [`:host{outline:0}`],
                providers: [NGQ_DATETIME_VALUE_ACCESSOR]
            },] },
];
/** @nocollapse */
NgqDatepickerComponent.ctorParameters = () => [];
NgqDatepickerComponent.propDecorators = {
    "hideIcon": [{ type: Input },],
    "id": [{ type: Input },],
    "class": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "input": [{ type: ViewChild, args: ['input',] },],
    "onTouched": [{ type: HostListener, args: ['blur',] },],
    "datePickerOptions": [{ type: Input, args: ['opts',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NgqDatepickerModule {
}
NgqDatepickerModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [NgqDatepickerComponent],
                exports: [NgqDatepickerComponent]
            },] },
];
/** @nocollapse */
NgqDatepickerModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { NgqDatepickerModule, NgqDatepickerComponent as ɵa };
//# sourceMappingURL=ngq-datepicker.js.map
